@@ -22,6 +22,11 @@
 #'               quantiles in `quantiles` model etc.
 #'               These labels are used in various print and plot outputs.
 #'               Comparable models (e.g. in [baggr_compare]) should have same `effect`.
+#' @param covariates Character vector with column names in `data`. The corresponding columns are used as
+#'                   covariates (fixed effects) in the meta-regression model (in case of aggregate data).
+#'                   In the case of individual level data the model does not differentiate between group-level
+#'                   variables (same values of the covariate for all rows related to a given group) and
+#'                   individual-level covariates.
 #' @param prior_hypermean prior distribution for hypermean; you can use "plain text" notation like
 #'              `prior_hypermean=normal(0,100)` or `uniform(-10, 10)`.
 #'              See Details:Priors below for more possible specifications.
@@ -31,8 +36,11 @@
 #'                       by Rubin and `"mutau"`` models;
 #'                       same rules apply as for `_hypermean`;
 #' @param prior_hypercor prior for hypercorrelation matrix, used by the `"mutau"` model
+#' @param prior_beta prior for regression coefficients if `covariates` are specified; will default to
+#'                       experimental normal(0, 10^2) distribution
 #' @param prior alternative way to specify all priors as a named list with `hypermean`,
-#'              `hypersd`, `hypercor`, e.g. `prior = list(hypermean = normal(0,10))`
+#'              `hypersd`, `hypercor`, `beta`, analogous to `prior_` arguments above,
+#'              e.g. `prior = list(hypermean = normal(0,10), beta = uniform(-50, 50))`
 #' @param ppd       logical; use prior predictive distribution? (_p.p.d._) Default is no.
 #'                  If `ppd=TRUE`, Stan model will sample from the prior distributions
 #'                  and ignore `data` in inference. However, `data` argument might still
@@ -47,6 +55,7 @@
 #'                  (with values between 0 and 1)
 #' @param test_data data for cross-validation; NULL for no validation, otherwise a data frame
 #'                  with the same columns as `data` argument
+#' @param silent Whether to silence messages about prior settings and about other automatic behaviour.
 #' @param warn print an additional warning if Rhat exceeds 1.05
 #' @param ... extra options passed to Stan function, e.g. \code{control = list(adapt_delta = 0.99)},
 #'            number of iterations etc.
@@ -68,24 +77,50 @@
 #' For individual level data three columns are needed: outcome, treatment, group. These
 #' are identified by using the `outcome`, `treatment` and `group` arguments.
 #'
-#' When working with individual-level data,
-#' many data preparation steps (summarising, standardisation etc.)
-#' can be done through a helper function [prepare_ma].
-#' Using it will also automatically format data inputs to be
-#' work with `baggr()`.
+#' Many data preparation steps can be done through a helper function [prepare_ma].
+#' It can convert individual to summary-level data, calculate
+#' odds/risk ratios (with/without corrections) in binary data, standardise variables and more.
+#' Using it will automatically format data inputs to work with `baggr()`.
+#'
 #'
 #' __Models.__ Available models are:
 #'
-#' * for the means: `"rubin"` model for average treatment effect, `"mutau"`
+#' * for the __continuous variable__ means:
+#'   `"rubin"` model for average treatment effect, `"mutau"`
 #'   version which takes into account means of control groups, `"full"`,
 #'   which works with individual-level data
-#' * "quantiles" model is also available (see Meager, 2019 in references)
+#' * for __continuous variable quantiles__: `"quantiles"`` model
+#'   (see Meager, 2019 in references)
+#' * for __binary data__: `"logit"` model can be used on individual-level data;
+#'   you can also analyse continuous statistics such as
+#'   log odds ratios and logs risk ratios using the models listed above;
+#'   see `vignette("baggr_binary")` for tutorial with examples
 #'
 #'  If no model is specified, the function tries to infer the appropriate
 #'  model automatically.
 #'  Additionally, the user must specify type of pooling.
 #'  The default is always partial pooling.
 #'
+#'
+#' __Covariates.__
+#' Both aggregate and individual-level data can include extra columns, given by `covariates` argument
+#' (specified as a character vector of column names) to be used in regression models.
+#'  We also refer to impact of these covariates as _fixed effects_.
+#'
+#' Two types of covariates may be present in your data:
+#'
+#' * In `"rubin"` and `"mutau"` models, covariates that __change according to group unit__.
+#'   In that case, the model accounting
+#'   for the group covariates is a
+#'   [meta-regression](https://handbook-5-1.cochrane.org/chapter_9/9_6_4_meta_regression.htm)
+#'   model. It can be modelled on summary-level data.
+#' * In `"logit"` and `"full"` models, covariates that __change according to individual unit__.
+#'   Then, the model can be called a
+#'   [mixed model](https://stats.stackexchange.com/questions/4700/what-is-the-difference-between-fixed-effect-random-effect-and-mixed-effect-mode/252888)
+#'   . It has to be fitted to individual-level data. Note that the first case can also be
+#'   accounted for by using a mixed model.
+#'
+#'
 #' __Priors.__ It is optional to specify priors yourself,
 #' as the package will try propose an appropriate
 #' prior for the input data if you do not pass a `prior` argument.
@@ -93,6 +128,19 @@
 #' (or re-using between models), a single `prior = list(...)` argument can be used instead.
 #' Appropriate examples are given in `vignette("baggr")`.
 #'
+#' __Outputs.__ By default, some outputs are printed. There is also a
+#' plot method for _baggr_ objects which you can access via [baggr_plot] (or simply `plot()`).
+#' Other standard functions for working with `baggr` object are
+#'
+#' * [treatment_effect] for distribution of hyperparameters
+#' * [group_effects] for distributions of group-specific parameters
+#' * [fixed_effects] for coefficients in (meta-)regression
+#' * [effect_draw] and [effect_plot] for posterior predictive distributions
+#' * [baggr_compare] for comparing multiple `baggr` models
+#' * [loocv] for cross-validation
+#' * [pp_check] for posterior predictive checks
+#'
+#'
 #' @author Witold Wiecek, Rachael Meager
 #'
 #' @examples
@@ -100,16 +148,18 @@
 #'                         "se" = rep(1, 8),
 #'                         "state" = datasets::state.name[1:8])
 #' baggr(df_pooled) #baggr automatically detects the input data
-#' # correct labels, different pooling & passing some options to Stan
+#' # same model, but with correct labels,
+#' # different pooling & passing some options to Stan
 #' baggr(df_pooled, group = "state", pooling = "full", iter = 500)
-#' #change the priors:
-#' baggr(df_pooled, prior_hypermean = normal(5,5))
+#' # model with different (very informative) priors
+#' baggr(df_pooled, prior_hypersd = normal(0, 2))
 #'
+#' \donttest{
 #' # "mu & tau" model, using a built-in dataset
 #' # prepare_ma() can summarise individual-level data
-#' \donttest{
-#' microcredit_summary_data <- prepare_ma(microcredit_simplified,
-#'                                        outcome = "consumerdurables")
+#' ms <- microcredit_simplified
+#' ms$outcome <- microcredit_simplified$consumerdurables + 1
+#' microcredit_summary_data <- prepare_ma(ms)
 #' baggr(microcredit_summary_data, model = "mutau",
 #'       pooling = "partial", prior_hypercor = lkj(1),
 #'       prior_hypersd = normal(0,10),
@@ -123,13 +173,15 @@
 
 baggr <- function(data, model = NULL, pooling = "partial",
                   effect = NULL,
+                  covariates = c(),
                   prior_hypermean = NULL, prior_hypersd = NULL, prior_hypercor=NULL,
+                  prior_beta = NULL,
                   # log = FALSE, cfb = FALSE, standardise = FALSE,
                   # baseline = NULL,
                   prior = NULL, ppd = FALSE,
                   test_data = NULL, quantiles = seq(.05, .95, .1),
                   outcome = "outcome", group = "group", treatment = "treatment",
-                  warn = TRUE, ...) {
+                  silent = FALSE, warn = TRUE, ...) {
 
   # check that it is data.frame of at least 1 row
   if(!inherits(data, "data.frame") || nrow(data) == 1)
@@ -147,11 +199,13 @@ baggr <- function(data, model = NULL, pooling = "partial",
 
   stan_data <- convert_inputs(data,
                               model,
+                              covariates = covariates,
                               quantiles = quantiles,
                               outcome = outcome,
                               group = group,
                               treatment = treatment,
-                              test_data = test_data)
+                              test_data = test_data,
+                              silent = silent)
   # model might've been chosen automatically (if NULL)
   # within convert_inptuts(), otherwise it's unchanged
   model <- attr(stan_data, "model")
@@ -192,15 +246,16 @@ baggr <- function(data, model = NULL, pooling = "partial",
   if(is.null(prior))
     prior <- list(hypermean = prior_hypermean,
                   hypercor  = prior_hypercor,
-                  hypersd   = prior_hypersd)
+                  hypersd   = prior_hypersd,
+                  beta      = prior_beta)
   else {
-    if(!is.null(prior_hypermean) ||
+    if(!is.null(prior_hypermean) || !is.null(prior_beta) ||
        !is.null(prior_hypercor)  || !is.null(prior_hypersd))
       message("Both 'prior' and 'prior_' arguments specified. Using 'prior' only.")
     if(class(prior) != "list" ||
-       !all(names(prior) %in% c('hypermean', 'hypercor', 'hypersd')))
+       !all(names(prior) %in% c('hypermean', 'hypercor', 'hypersd', 'beta')))
       stop(paste("Prior argument must be a list with names",
-                 "'hypermean', 'hypercor', 'hypersd'"))
+                 "'hypermean', 'hypercor', 'hypersd', 'beta'"))
   }
   # If extracting prior from another model, we need to do a swapsie switcheroo:
   stan_args <- list(...)
@@ -208,7 +263,9 @@ baggr <- function(data, model = NULL, pooling = "partial",
     formatted_prior <- stan_args$formatted_prior
     stan_args$formatted_prior <- NULL
   } else { # extract priors from inputs & fill in missing priors
-    formatted_prior <- prepare_prior(prior, data, stan_data, model, quantiles = quantiles)
+    formatted_prior <- prepare_prior(prior, data, stan_data, model,
+                                     pooling, covariates, quantiles = quantiles,
+                                     silent = silent)
   }
   for(nm in names(formatted_prior))
     stan_data[[nm]] <- formatted_prior[[nm]]
@@ -232,6 +289,7 @@ baggr <- function(data, model = NULL, pooling = "partial",
     "n_groups" = n_groups,
     "n_parameters" = ifelse(model == "quantiles", length(quantiles), 1),
     "effects" = effect,
+    "covariates" = covariates,
     "pooling" = pooling,
     "fit" = fit,
     "model" = model
@@ -277,9 +335,10 @@ check_if_baggr <- function(bg) {
 }
 
 remove_data_for_prior_pred <- function(data) {
-  scalars_to0 <- c("K", "N")
-  vectors_to_remove <- c("tau_hat_k", "se_tau_k",
+  scalars_to0 <- c("K", "N", "Nc")
+  vectors_to_remove <- c("theta_hat_k", "se_theta_k",
                          "y", "treatment", "site")
+  matrices_to_remove <- c("X")
   for(nm in scalars_to0)
     if(!is.null(data[[nm]]))
       data[[nm]] <- 0
@@ -288,5 +347,9 @@ remove_data_for_prior_pred <- function(data) {
     if(!is.null(data[[nm]]))
       data[[nm]] <- array(0, dim = c(0))
 
+  for(nm in matrices_to_remove)
+    if(!is.null(data[[nm]]))
+      data[[nm]] <- array(0, dim = c(0,0))
+
   data
 }
