@@ -1,20 +1,25 @@
 #' Convert inputs for baggr models
 #'
 #' Converts data to Stan inputs, checks integrity of data
-#' and suggests default model if needed. Typically used
-#' automatically by [baggr] but useful for debugging.
+#' and suggests default model if needed. Typically all of this is
+#' done automatically by [baggr], __this function is only for debugging__
+#' or running models "by hand".
 #'
 #' @param data `data.frame`` with desired modelling input
 #' @param model valid model name used by baggr;
 #'              see [baggr] for allowed models
 #'              if `model = NULL`, this function will try to find appropriate model
 #'              automatically
+#' @param covariates Character vector with column names in `data`.
+#'                   The corresponding columns are used as
+#'                   covariates (fixed effects) in the meta-regression model.
 #' @param quantiles vector of quantiles to use (only applicable if `model = "quantiles"`)
 #' @param group name of the column with grouping variable
 #' @param outcome name of column with outcome variable (designated as string)
 #' @param treatment name of column with treatment variable
 #' @param test_data same format as `data` argument, gets left aside for
 #'                  testing purposes (see [baggr])
+#' @param silent Whether to print messages when evaluated
 #' @return R structure that's appropriate for use by [baggr] Stan models;
 #'         `group_label`, `model` and `n_groups` are included as attributes
 #'         and are necessary for [baggr] to work correctly
@@ -25,7 +30,8 @@
 #'
 #' @author Witold Wiecek
 #' @examples
-#' # simple meta-analysis example:
+#' # simple meta-analysis example,
+#' # this is the formatted input for Stan models in baggr():
 #' convert_inputs(schools, "rubin")
 #' @export
 
@@ -35,7 +41,9 @@ convert_inputs <- function(data,
                            group  = "group",
                            outcome   = "outcome",
                            treatment = "treatment",
-                           test_data = NULL) {
+                           covariates = c(),
+                           test_data = NULL,
+                           silent = FALSE) {
 
   # check what kind of data is required for the model & what's available
   model_data_types <- c("rubin" = "pool_noctrl_narrow",
@@ -54,7 +62,8 @@ convert_inputs <- function(data,
   if(!is.null(test_data)){
     available_data_test <- detect_input_type(test_data, group, treatment, outcome)
     if(available_data != available_data_test)
-      stop("'test_data' is of type ", available_data_test, " and 'data' is of type ", available_data)
+      stop("'test_data' is of type ", available_data_test,
+           " and 'data' is of type ", available_data)
   }
   # if(available_data == "unknown")
   # stop("Cannot automatically determine type of input data.")
@@ -70,10 +79,11 @@ convert_inputs <- function(data,
       check_columns(data, outcome, group, treatment)
   }
   if(is.null(model)) {
-    message("Attempting to infer the correct model for data.")
     # we take FIRST MODEL THAT SUITS OUR DATA!
     model <- names(model_data_types)[which(model_data_types == available_data)[1]]
-    message(paste0("Chosen model ", model))
+    if(!silent)
+      message(paste0("Automatically set model to ", crayon::bold(model_names[model]),
+                     " from data."))
   } else {
     if(!(model %in% names(model_data_types)))
       stop("Unrecognised model, can't format data.")
@@ -123,20 +133,35 @@ convert_inputs <- function(data,
         treatment = data[[treatment]],
         site = group_numeric
       )
-    }
-    if(model == "logit") {
+    # }
+    # if(model == "logit") {
       if(is.null(test_data)) {
         out$N_test <- 0
         out$K_test <- 0
         out$test_y <- array(0, dim = 0)
         out$test_site <- array(0, dim = 0)
         out$test_treatment <- array(0, dim = 0)
+        if(model == "full")
+          out$test_sigma_y_k <- array(0, dim = 0)
+
       } else {
         out$N_test <- nrow(test_data)
         out$K_test <- max(group_numeric_test)
         out$test_y <- test_data[[outcome]]
         out$test_treatment <- test_data[[treatment]]
         out$test_site <- group_numeric_test
+        # calculate SEs in each test group
+        if(model == "full"){
+          se_in_each_group <- sapply(
+            1:max(group_numeric_test), function(i) {
+              n <- sum(group_numeric_test == i)
+              sd(test_data[[outcome]][group_numeric_test == i])/sqrt(n)
+          })
+          if(any(is.na(se_in_each_group)))
+            stop("Cannot calculate SE in groups in test data. Each out-of-sample ",
+                 "group must be of size at least 2.")
+          out$test_sigma_y_k <- array(se_in_each_group, dim = max(group_numeric_test))
+        }
       }
     }
     if(model == "quantiles"){
@@ -160,8 +185,8 @@ convert_inputs <- function(data,
       # Cross-validation:
       if(is.null(test_data)){
         out$K_test <- 0
-        out$test_tau_hat_k <- array(0, dim = 0)
-        out$test_se_k <- array(0, dim = 0)
+        out$test_theta_hat_k <- array(0, dim = 0)
+        out$test_se_theta_k <- array(0, dim = 0)
         out$test_y_0 <- array(0, dim = c(0, ncol(out$y_0)))
         out$test_y_1 <- array(0, dim = c(0, ncol(out$y_0)))
         out$test_Sigma_y_k_0 <- array(0, dim = c(0, ncol(out$y_0), ncol(out$y_0)))
@@ -190,21 +215,21 @@ convert_inputs <- function(data,
     check_columns_numeric(data[,c("tau", "se")])
     out <- list(
       K = nrow(data),
-      tau_hat_k = data[["tau"]],
-      se_tau_k = data[["se"]]
+      theta_hat_k = data[["tau"]],
+      se_theta_k = data[["se"]]
     )
     if(is.null(test_data)){
       out$K_test <- 0
-      out$test_tau_hat_k <- array(0, dim = 0)
-      out$test_se_k <- array(0, dim = 0)
+      out$test_theta_hat_k <- array(0, dim = 0)
+      out$test_se_theta_k <- array(0, dim = 0)
     } else {
       if(is.null(test_data[["tau"]]) ||
          is.null(test_data[["se"]]))
         stop("Test data must be of the same format as input data")
       out$K_test <- nrow(test_data)
       # remember that for 1-dim cases we need to pass array()
-      out$test_tau_hat_k <- array(test_data[["tau"]], dim = c(nrow(test_data)))
-      out$test_se_k <- array(test_data[["se"]], dim = c(nrow(test_data)))
+      out$test_theta_hat_k <- array(test_data[["tau"]], dim = c(nrow(test_data)))
+      out$test_se_theta_k <- array(test_data[["se"]], dim = c(nrow(test_data)))
     }
   }
 
@@ -223,13 +248,13 @@ convert_inputs <- function(data,
       P = 2, #fixed for this case
       # Remember, first row is always mu (baseline), second row is tau (effect)
       # (Has to be consistent against ordering of prior values.)
-      tau_hat_k = matrix(c(data[["mu"]], data[["tau"]]), 2, nr, byrow = T),
-      se_tau_k = matrix(c(data[["se.mu"]], data[["se.tau"]]), 2, nr, byrow = T)
+      theta_hat_k = matrix(c(data[["mu"]], data[["tau"]]), 2, nr, byrow = T),
+      se_theta_k = matrix(c(data[["se.mu"]], data[["se.tau"]]), 2, nr, byrow = T)
     )
     if(is.null(test_data)){
       out$K_test <- 0
-      out$test_tau_hat_k <- array(0, dim = c(2,0))
-      out$test_se_k <- array(0, dim = c(2,0))
+      out$test_theta_hat_k <- array(0, dim = c(2,0))
+      out$test_se_theta_k <- array(0, dim = c(2,0))
     } else {
       if(is.null(test_data[["mu"]]) ||
          is.null(test_data[["tau"]]) ||
@@ -237,13 +262,53 @@ convert_inputs <- function(data,
          is.null(test_data[["se.tau"]]))
         stop("Test data must be of the same format as input data")
       out$K_test <- nrow(test_data)
-      out$test_tau_hat_k <- matrix(c(test_data[["mu"]], test_data[["tau"]]),
-                                   2, nrow(test_data), byrow = T)
-      out$test_se_k <- matrix(c(test_data[["se.mu"]], test_data[["se.tau"]]),
-                              2, nrow(test_data), byrow = T)
+      out$test_theta_hat_k <- matrix(c(test_data[["mu"]], test_data[["tau"]]),
+                                     2, nrow(test_data), byrow = T)
+      out$test_se_theta_k <- matrix(c(test_data[["se.mu"]], test_data[["se.tau"]]),
+                                    2, nrow(test_data), byrow = T)
     }
   }
 
+  # Include covariates ------
+  # if(required_data != "individual") {
+    if(length(covariates) > 0) {
+
+      if(!all(covariates %in% names(data)))
+        stop(paste0("Covariates ",
+                    paste(covariates[!(covariates %in% names(data))], collapse=","),
+                    " are not columns in input data"))
+
+      # Test_data preparation
+      if(!is.null(test_data)){
+        data_bind <- try(rbind(data[,covariates, drop = FALSE],
+                               test_data[,covariates, drop = FALSE]))
+        if(class(data_bind) == "try-error")
+          stop("Cannot bind data and test_data. Ensure that all ",
+               "covariates are present and same levels are used.")
+        data_bind$tau <- 0
+
+        out$X_test <- model.matrix(as.formula(
+          paste("tau ~", paste(covariates, collapse="+"), "-1")),
+          data=data_bind[(nrow(data)+1):nrow(data_bind),])
+      } else {
+        data_bind <- data[,covariates, drop = FALSE]
+        data_bind$tau <- 0
+        out$X_test <- array(0, dim=c(0, length(covariates)))
+      }
+
+      out$X <- model.matrix(as.formula(
+        paste("tau ~", paste(covariates, collapse="+"), "-1")),
+        data=data_bind[1:nrow(data),])
+      out$Nc <- length(covariates)
+
+    } else {
+      out$Nc <- length(covariates)
+      out$X <- array(0, dim=c(nrow(data), 0))
+      out$X_test <- array(0, dim=c(ifelse(is.null(test_data), 0, nrow(test_data)), 0))
+    }
+  # }
+
+
   na_cols <- unlist(lapply(out, function(x) any(is.na(x))))
   if(any(na_cols))
     stop(paste0("baggr() does not allow NA values in inputs (see vectors ",
