@@ -2,7 +2,7 @@
 # given a data.frame try to infer
 # what kind of data we're dealing with
 
-detect_input_type <- function(data, group) {
+detect_input_type <- function(data, group, treatment, outcome) {
   # if(class == "baggr_data")
   if(!("data.frame" %in% class(data)))
     stop("Can't detect input type because it's not data.frame")
@@ -18,9 +18,13 @@ detect_input_type <- function(data, group) {
                       names(data)))))
     return("pool_wide")
 
-  if(!is.null(data[[group]]))
-    if(nrow(data) > length(unique(data[[group]])))
-      return("individual")
-
+  if(!is.null(data[[group]])){
+    if(nrow(data) > length(unique(data[[group]]))){
+      if(is_binary(data[[outcome]]))
+        return("individual_binary")
+      else
+        return("individual")
+    }
+  }
   return("unknown")
 }
